import * as React from 'react';
import styledComponents from 'styled-components';
import { fadeIn } from '../../keyframes';

export interface FullScreenOverlayProps {
  isActive: boolean;
  action: () => void;
  children: React.ReactNode;
  className?: string;
  showAnimation?: boolean;
  style?: React.CSSProperties;
}

// full screen overlay
export const FullScreenOverlay: React.StatelessComponent<FullScreenOverlayProps> = (props) => {
  const { isActive, action, children, className, showAnimation, style } = props;

  const StyledOverlay = styledComponents.div`
    display: ${isActive ? 'flex' : 'none'};
    position: fixed;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%;
    z-index: 999;
    background: rgba(0, 0, 0, 0.75);
    overflow: auto;
    justify-content: center;
    align-items: center;
    animation: ${showAnimation ? fadeIn : 'none'} 0.3s;
  `;

  return(
    <StyledOverlay
      className={['full-screen-overlay', className].join(' ')}
      onClick={action}
      style={style} // override with user style
    >
      {children}
    </StyledOverlay>
  );
};
