import * as React from 'react';

export interface ModalContainerProps {
  activeOnLoad?: boolean;
  children: (
    openModal: () => void,
    closeModal: () => void,
    isActive: boolean,
  ) => React.ReactNode;
}

export interface ModalContainerState {
  isActive: boolean;
}

export class ModalContainer extends React.Component<ModalContainerProps, ModalContainerState> {
  constructor(props) {
    super(props);
    this.state = {
      isActive: this.props.activeOnLoad || false,
    };
  }

  public componentDidMount() {
    // close modal when esc key is pressed
    document.addEventListener('keyup', (e) => {
      if (this.state.isActive && e.keyCode === 27) {
        this.closeModal();
      }
    });
  }

  public openModal = (): void => {
    this.setState({ isActive: true });
  }

  public closeModal = (): void => {
    this.setState({ isActive: false });
  }

  public render() {
    return this.props.children(this.openModal, this.closeModal, this.state.isActive);
  }
}
