import * as React from 'react';
import styledComponents from 'styled-components';
import { Button } from '../../Atoms/Button';
import { scaleDown } from '../../keyframes';

export interface ModalBoxProps {
  isActive: boolean;
  closeModal: () => void;
  children: React.ReactNode;
  className?: string;
  showCloseButton?: boolean;
  showAnimation?: boolean;
  style?: React.CSSProperties;
  closeButtonStyle?: React.CSSProperties;
}

// actual modal itself
export const ModalBox: React.StatelessComponent<ModalBoxProps> = (props) => {
  const { closeModal, children, className, showCloseButton, showAnimation, style, closeButtonStyle } = props;

  const StyledModalBox = styledComponents.div`
    background: white;
    box-sizing: border-box;
    position: relative;
    z-index: 1000;
    animation: ${showAnimation ? scaleDown : 'none'} 0.3s;
  `;

  const DefaultCloseButtonStyle: React.CSSProperties = {
    position: 'absolute',
    width: '30px',
    height: '30px',
    top: '-10px',
    right: '-10px',
    textAlign: 'center',
    padding: '9px 0',
    fontSize: '20px',
    lineHeight: '0',
    borderRadius: '15px',
  };

  return(
    <StyledModalBox
        className={['modal-box', className].join(' ')}
        onClick={(e) => { e.stopPropagation(); }}
        style={style} // override with user style
    >
    {
      showCloseButton &&
      <Button
        action={closeModal}
        text="×"
        className="modal-close-button"
        style={Object.assign(DefaultCloseButtonStyle, closeButtonStyle)}
      />
    }
      {children}
    </StyledModalBox>
  );
};
