import * as React from 'react';
import { FullScreenOverlay } from '../../Atoms/FullScreenOverlay';
import { ModalBox } from '../../Molecules/ModalBox';

export interface ModalProps {
  isActive: boolean;
  closeModal: () => void;
  children: React.ReactNode;
  className?: string;
  showCloseButton?: boolean;
  showAnimation?: boolean;
  modalBoxStyle?: React.CSSProperties;
  closeButtonStyle?: React.CSSProperties;
  overlayStyle?: React.CSSProperties;
}

export const Modal: React.StatelessComponent<ModalProps> = (props) => {
  const {
    isActive, closeModal, children, className, showCloseButton,
    showAnimation, modalBoxStyle, closeButtonStyle, overlayStyle,
  } = props;

  return(
    <FullScreenOverlay
      isActive={isActive}
      action={closeModal}
      className={className}
      showAnimation={showAnimation}
      style={overlayStyle}
    >
      <ModalBox
        isActive={isActive}
        closeModal={closeModal}
        className={className}
        showCloseButton={showCloseButton}
        showAnimation={showAnimation}
        style={modalBoxStyle}
        closeButtonStyle={closeButtonStyle}
      >
        {children}
      </ModalBox>
    </FullScreenOverlay>
  );
};
