import ava from 'ava';
import * as React from 'react';
import * as ReactTestRenderer from 'react-test-renderer';
import { Modal, ModalContainer } from '.';

ava('can use ava', (t) => {
  t.pass();
});

const modalFactory = (showCloseButton: boolean) => ReactTestRenderer.create(
  <ModalContainer
    activeOnLoad={true}
  >
    {(openModal, closeModal, isActive) => (
      <>
        <button onClick={openModal}>open</button>
        <Modal
          isActive={isActive}
          closeModal={closeModal}
          showCloseButton={showCloseButton}
          className="test"
        >
          <h1>content</h1>
        </Modal>
      </>
    )}
  </ModalContainer>,
).root;

ava('modal should render open button', (t) => {
  const result = modalFactory(true);
  t.is(result.children[0].props.children, 'open');
  t.is(result.children[0].type, 'button');
  t.truthy(true);
});

ava('modal should have close button', (t) => {
  const result = modalFactory(true);
  const modalBox = result.findByProps({ className: 'modal-box test' });
  t.is(modalBox.props.children[0].props.text, '×');
  t.is(modalBox.props.children[0].props.className, 'modal-close-button');
});

ava('modal should not have close button', (t) => {
  const result = modalFactory(false);
  t.throws(
    () => result.findByProps({ className: 'modal-close-button' }),
    null,
    'No instances found with props: {"className":"modal-close-button"}',
  );
});

ava('modal should have content', (t) => {
  const result = modalFactory(true);
  const modalBox = result.findByProps({ className: 'modal-box test' });
  t.is(modalBox.props.children[1].type, 'h1');
  t.is(modalBox.props.children[1].props.children, 'content');
});
